.. armsim documentation master file, created by
   sphinx-quickstart on Wed May  6 18:04:10 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to armsim's documentation!
==================================

armsim is a project which aims to simulate an AT91SAM9260 processor, 
to do so it needs the ARMv5TE instruction set (it should also support 
Thumb and Jazelle instructions later)

You can find a page of resources, where all the documentation links should be
found

Contents:

.. toctree::
   :maxdepth: 2

   users/installation
   users/usage
   developers/api/index
   developers/contribute
   resources

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

